==> org-lsst-sal-camera-2.6.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket4_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket4_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus4_clampState;

  private final int clampxminus4_filterPositionSensorValue;

  private final int clampxminus4_filterPresenceOffset2;

  private final String clampxminus4_filterPresenceStatus;

  private final int clampxminus4_lockSensorOffset1;

  private final int clampxminus4_lockSensorValue;

  private final String clampxminus4_lockStatus;

  private final String clampxplus4_clampState;

  private final int clampxplus4_filterPositionSensorValue;

  private final int clampxplus4_filterPresenceOffset2;

  private final String clampxplus4_filterPresenceStatus;

  private final int clampxplus4_lockSensorOffset1;

  private final int clampxplus4_lockSensorValue;

  private final String clampxplus4_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final int filterID;

  private final String ioStatus;

  public Fcs_Carousel_Socket4_TrendingTelemetry(boolean atStandby, String clampxminus4_clampState,
      int clampxminus4_filterPositionSensorValue, int clampxminus4_filterPresenceOffset2,
      String clampxminus4_filterPresenceStatus, int clampxminus4_lockSensorOffset1,
      int clampxminus4_lockSensorValue, String clampxminus4_lockStatus,
      String clampxplus4_clampState, int clampxplus4_filterPositionSensorValue,
      int clampxplus4_filterPresenceOffset2, String clampxplus4_filterPresenceStatus,
      int clampxplus4_lockSensorOffset1, int clampxplus4_lockSensorValue,
      String clampxplus4_lockStatus, String clampsState, boolean empty, int filterID,
      String ioStatus) {
    this.atStandby = atStandby;
    this.clampxminus4_clampState = clampxminus4_clampState;
    this.clampxminus4_filterPositionSensorValue = clampxminus4_filterPositionSensorValue;
    this.clampxminus4_filterPresenceOffset2 = clampxminus4_filterPresenceOffset2;
    this.clampxminus4_filterPresenceStatus = clampxminus4_filterPresenceStatus;
    this.clampxminus4_lockSensorOffset1 = clampxminus4_lockSensorOffset1;
    this.clampxminus4_lockSensorValue = clampxminus4_lockSensorValue;
    this.clampxminus4_lockStatus = clampxminus4_lockStatus;
    this.clampxplus4_clampState = clampxplus4_clampState;
    this.clampxplus4_filterPositionSensorValue = clampxplus4_filterPositionSensorValue;
    this.clampxplus4_filterPresenceOffset2 = clampxplus4_filterPresenceOffset2;
    this.clampxplus4_filterPresenceStatus = clampxplus4_filterPresenceStatus;
    this.clampxplus4_lockSensorOffset1 = clampxplus4_lockSensorOffset1;
    this.clampxplus4_lockSensorValue = clampxplus4_lockSensorValue;
    this.clampxplus4_lockStatus = clampxplus4_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterID = filterID;
    this.ioStatus = ioStatus;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus4_clampState() {
    return clampxminus4_clampState;
  }

  public int getClampxminus4_filterPositionSensorValue() {
    return clampxminus4_filterPositionSensorValue;
  }

  public int getClampxminus4_filterPresenceOffset2() {
    return clampxminus4_filterPresenceOffset2;
  }

  public String getClampxminus4_filterPresenceStatus() {
    return clampxminus4_filterPresenceStatus;
  }

  public int getClampxminus4_lockSensorOffset1() {
    return clampxminus4_lockSensorOffset1;
  }

  public int getClampxminus4_lockSensorValue() {
    return clampxminus4_lockSensorValue;
  }

  public String getClampxminus4_lockStatus() {
    return clampxminus4_lockStatus;
  }

  public String getClampxplus4_clampState() {
    return clampxplus4_clampState;
  }

  public int getClampxplus4_filterPositionSensorValue() {
    return clampxplus4_filterPositionSensorValue;
  }

  public int getClampxplus4_filterPresenceOffset2() {
    return clampxplus4_filterPresenceOffset2;
  }

  public String getClampxplus4_filterPresenceStatus() {
    return clampxplus4_filterPresenceStatus;
  }

  public int getClampxplus4_lockSensorOffset1() {
    return clampxplus4_lockSensorOffset1;
  }

  public int getClampxplus4_lockSensorValue() {
    return clampxplus4_lockSensorValue;
  }

  public String getClampxplus4_lockStatus() {
    return clampxplus4_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public int getFilterID() {
    return filterID;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket4_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus4_clampState=" + clampxminus4_clampState +
        ", clampxminus4_filterPositionSensorValue=" + clampxminus4_filterPositionSensorValue +
        ", clampxminus4_filterPresenceOffset2=" + clampxminus4_filterPresenceOffset2 +
        ", clampxminus4_filterPresenceStatus=" + clampxminus4_filterPresenceStatus +
        ", clampxminus4_lockSensorOffset1=" + clampxminus4_lockSensorOffset1 +
        ", clampxminus4_lockSensorValue=" + clampxminus4_lockSensorValue +
        ", clampxminus4_lockStatus=" + clampxminus4_lockStatus +
        ", clampxplus4_clampState=" + clampxplus4_clampState +
        ", clampxplus4_filterPositionSensorValue=" + clampxplus4_filterPositionSensorValue +
        ", clampxplus4_filterPresenceOffset2=" + clampxplus4_filterPresenceOffset2 +
        ", clampxplus4_filterPresenceStatus=" + clampxplus4_filterPresenceStatus +
        ", clampxplus4_lockSensorOffset1=" + clampxplus4_lockSensorOffset1 +
        ", clampxplus4_lockSensorValue=" + clampxplus4_lockSensorValue +
        ", clampxplus4_lockStatus=" + clampxplus4_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterID=" + filterID +", ioStatus=" + ioStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus4_clampState;

    private int clampxminus4_filterPositionSensorValue;

    private int clampxminus4_filterPresenceOffset2;

    private String clampxminus4_filterPresenceStatus;

    private int clampxminus4_lockSensorOffset1;

    private int clampxminus4_lockSensorValue;

    private String clampxminus4_lockStatus;

    private String clampxplus4_clampState;

    private int clampxplus4_filterPositionSensorValue;

    private int clampxplus4_filterPresenceOffset2;

    private String clampxplus4_filterPresenceStatus;

    private int clampxplus4_lockSensorOffset1;

    private int clampxplus4_lockSensorValue;

    private String clampxplus4_lockStatus;

    private String clampsState;

    private boolean empty;

    private int filterID;

    private String ioStatus;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus4_clampState(String clampxminus4_clampState) {
      this.clampxminus4_clampState = clampxminus4_clampState;
      return this;
    }

    public Builder clampxminus4_filterPositionSensorValue(
        int clampxminus4_filterPositionSensorValue) {
      this.clampxminus4_filterPositionSensorValue = clampxminus4_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus4_filterPresenceOffset2(int clampxminus4_filterPresenceOffset2) {
      this.clampxminus4_filterPresenceOffset2 = clampxminus4_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus4_filterPresenceStatus(String clampxminus4_filterPresenceStatus) {
      this.clampxminus4_filterPresenceStatus = clampxminus4_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus4_lockSensorOffset1(int clampxminus4_lockSensorOffset1) {
      this.clampxminus4_lockSensorOffset1 = clampxminus4_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus4_lockSensorValue(int clampxminus4_lockSensorValue) {
      this.clampxminus4_lockSensorValue = clampxminus4_lockSensorValue;
      return this;
    }

    public Builder clampxminus4_lockStatus(String clampxminus4_lockStatus) {
      this.clampxminus4_lockStatus = clampxminus4_lockStatus;
      return this;
    }

    public Builder clampxplus4_clampState(String clampxplus4_clampState) {
      this.clampxplus4_clampState = clampxplus4_clampState;
      return this;
    }

    public Builder clampxplus4_filterPositionSensorValue(
        int clampxplus4_filterPositionSensorValue) {
      this.clampxplus4_filterPositionSensorValue = clampxplus4_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus4_filterPresenceOffset2(int clampxplus4_filterPresenceOffset2) {
      this.clampxplus4_filterPresenceOffset2 = clampxplus4_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus4_filterPresenceStatus(String clampxplus4_filterPresenceStatus) {
      this.clampxplus4_filterPresenceStatus = clampxplus4_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus4_lockSensorOffset1(int clampxplus4_lockSensorOffset1) {
      this.clampxplus4_lockSensorOffset1 = clampxplus4_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus4_lockSensorValue(int clampxplus4_lockSensorValue) {
      this.clampxplus4_lockSensorValue = clampxplus4_lockSensorValue;
      return this;
    }

    public Builder clampxplus4_lockStatus(String clampxplus4_lockStatus) {
      this.clampxplus4_lockStatus = clampxplus4_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterID(int filterID) {
      this.filterID = filterID;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Fcs_Carousel_Socket4_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket4_TrendingTelemetry(atStandby, clampxminus4_clampState, clampxminus4_filterPositionSensorValue, clampxminus4_filterPresenceOffset2, clampxminus4_filterPresenceStatus, clampxminus4_lockSensorOffset1, clampxminus4_lockSensorValue, clampxminus4_lockStatus, clampxplus4_clampState, clampxplus4_filterPositionSensorValue, clampxplus4_filterPresenceOffset2, clampxplus4_filterPresenceStatus, clampxplus4_lockSensorOffset1, clampxplus4_lockSensorValue, clampxplus4_lockStatus, clampsState, empty, filterID, ioStatus);
    }
  }
}

==> org-lsst-sal-camera-3.0.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket4_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket4_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus4_clampState;

  private final int clampxminus4_filterPositionSensorValue;

  private final int clampxminus4_filterPresenceOffset2;

  private final String clampxminus4_filterPresenceStatus;

  private final int clampxminus4_lockSensorOffset1;

  private final int clampxminus4_lockSensorValue;

  private final String clampxminus4_lockStatus;

  private final String clampxplus4_clampState;

  private final int clampxplus4_filterPositionSensorValue;

  private final int clampxplus4_filterPresenceOffset2;

  private final String clampxplus4_filterPresenceStatus;

  private final int clampxplus4_lockSensorOffset1;

  private final int clampxplus4_lockSensorValue;

  private final String clampxplus4_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final String filterName;

  private final String ioStatus;

  private final int socketID;

  public Fcs_Carousel_Socket4_TrendingTelemetry(boolean atStandby, String clampxminus4_clampState,
      int clampxminus4_filterPositionSensorValue, int clampxminus4_filterPresenceOffset2,
      String clampxminus4_filterPresenceStatus, int clampxminus4_lockSensorOffset1,
      int clampxminus4_lockSensorValue, String clampxminus4_lockStatus,
      String clampxplus4_clampState, int clampxplus4_filterPositionSensorValue,
      int clampxplus4_filterPresenceOffset2, String clampxplus4_filterPresenceStatus,
      int clampxplus4_lockSensorOffset1, int clampxplus4_lockSensorValue,
      String clampxplus4_lockStatus, String clampsState, boolean empty, String filterName,
      String ioStatus, int socketID) {
    this.atStandby = atStandby;
    this.clampxminus4_clampState = clampxminus4_clampState;
    this.clampxminus4_filterPositionSensorValue = clampxminus4_filterPositionSensorValue;
    this.clampxminus4_filterPresenceOffset2 = clampxminus4_filterPresenceOffset2;
    this.clampxminus4_filterPresenceStatus = clampxminus4_filterPresenceStatus;
    this.clampxminus4_lockSensorOffset1 = clampxminus4_lockSensorOffset1;
    this.clampxminus4_lockSensorValue = clampxminus4_lockSensorValue;
    this.clampxminus4_lockStatus = clampxminus4_lockStatus;
    this.clampxplus4_clampState = clampxplus4_clampState;
    this.clampxplus4_filterPositionSensorValue = clampxplus4_filterPositionSensorValue;
    this.clampxplus4_filterPresenceOffset2 = clampxplus4_filterPresenceOffset2;
    this.clampxplus4_filterPresenceStatus = clampxplus4_filterPresenceStatus;
    this.clampxplus4_lockSensorOffset1 = clampxplus4_lockSensorOffset1;
    this.clampxplus4_lockSensorValue = clampxplus4_lockSensorValue;
    this.clampxplus4_lockStatus = clampxplus4_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterName = filterName;
    this.ioStatus = ioStatus;
    this.socketID = socketID;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus4_clampState() {
    return clampxminus4_clampState;
  }

  public int getClampxminus4_filterPositionSensorValue() {
    return clampxminus4_filterPositionSensorValue;
  }

  public int getClampxminus4_filterPresenceOffset2() {
    return clampxminus4_filterPresenceOffset2;
  }

  public String getClampxminus4_filterPresenceStatus() {
    return clampxminus4_filterPresenceStatus;
  }

  public int getClampxminus4_lockSensorOffset1() {
    return clampxminus4_lockSensorOffset1;
  }

  public int getClampxminus4_lockSensorValue() {
    return clampxminus4_lockSensorValue;
  }

  public String getClampxminus4_lockStatus() {
    return clampxminus4_lockStatus;
  }

  public String getClampxplus4_clampState() {
    return clampxplus4_clampState;
  }

  public int getClampxplus4_filterPositionSensorValue() {
    return clampxplus4_filterPositionSensorValue;
  }

  public int getClampxplus4_filterPresenceOffset2() {
    return clampxplus4_filterPresenceOffset2;
  }

  public String getClampxplus4_filterPresenceStatus() {
    return clampxplus4_filterPresenceStatus;
  }

  public int getClampxplus4_lockSensorOffset1() {
    return clampxplus4_lockSensorOffset1;
  }

  public int getClampxplus4_lockSensorValue() {
    return clampxplus4_lockSensorValue;
  }

  public String getClampxplus4_lockStatus() {
    return clampxplus4_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  public int getSocketID() {
    return socketID;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket4_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus4_clampState=" + clampxminus4_clampState +
        ", clampxminus4_filterPositionSensorValue=" + clampxminus4_filterPositionSensorValue +
        ", clampxminus4_filterPresenceOffset2=" + clampxminus4_filterPresenceOffset2 +
        ", clampxminus4_filterPresenceStatus=" + clampxminus4_filterPresenceStatus +
        ", clampxminus4_lockSensorOffset1=" + clampxminus4_lockSensorOffset1 +
        ", clampxminus4_lockSensorValue=" + clampxminus4_lockSensorValue +
        ", clampxminus4_lockStatus=" + clampxminus4_lockStatus +
        ", clampxplus4_clampState=" + clampxplus4_clampState +
        ", clampxplus4_filterPositionSensorValue=" + clampxplus4_filterPositionSensorValue +
        ", clampxplus4_filterPresenceOffset2=" + clampxplus4_filterPresenceOffset2 +
        ", clampxplus4_filterPresenceStatus=" + clampxplus4_filterPresenceStatus +
        ", clampxplus4_lockSensorOffset1=" + clampxplus4_lockSensorOffset1 +
        ", clampxplus4_lockSensorValue=" + clampxplus4_lockSensorValue +
        ", clampxplus4_lockStatus=" + clampxplus4_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterName=" + filterName +", ioStatus=" + ioStatus +
        ", socketID=" + socketID +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus4_clampState;

    private int clampxminus4_filterPositionSensorValue;

    private int clampxminus4_filterPresenceOffset2;

    private String clampxminus4_filterPresenceStatus;

    private int clampxminus4_lockSensorOffset1;

    private int clampxminus4_lockSensorValue;

    private String clampxminus4_lockStatus;

    private String clampxplus4_clampState;

    private int clampxplus4_filterPositionSensorValue;

    private int clampxplus4_filterPresenceOffset2;

    private String clampxplus4_filterPresenceStatus;

    private int clampxplus4_lockSensorOffset1;

    private int clampxplus4_lockSensorValue;

    private String clampxplus4_lockStatus;

    private String clampsState;

    private boolean empty;

    private String filterName;

    private String ioStatus;

    private int socketID;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus4_clampState(String clampxminus4_clampState) {
      this.clampxminus4_clampState = clampxminus4_clampState;
      return this;
    }

    public Builder clampxminus4_filterPositionSensorValue(
        int clampxminus4_filterPositionSensorValue) {
      this.clampxminus4_filterPositionSensorValue = clampxminus4_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus4_filterPresenceOffset2(int clampxminus4_filterPresenceOffset2) {
      this.clampxminus4_filterPresenceOffset2 = clampxminus4_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus4_filterPresenceStatus(String clampxminus4_filterPresenceStatus) {
      this.clampxminus4_filterPresenceStatus = clampxminus4_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus4_lockSensorOffset1(int clampxminus4_lockSensorOffset1) {
      this.clampxminus4_lockSensorOffset1 = clampxminus4_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus4_lockSensorValue(int clampxminus4_lockSensorValue) {
      this.clampxminus4_lockSensorValue = clampxminus4_lockSensorValue;
      return this;
    }

    public Builder clampxminus4_lockStatus(String clampxminus4_lockStatus) {
      this.clampxminus4_lockStatus = clampxminus4_lockStatus;
      return this;
    }

    public Builder clampxplus4_clampState(String clampxplus4_clampState) {
      this.clampxplus4_clampState = clampxplus4_clampState;
      return this;
    }

    public Builder clampxplus4_filterPositionSensorValue(
        int clampxplus4_filterPositionSensorValue) {
      this.clampxplus4_filterPositionSensorValue = clampxplus4_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus4_filterPresenceOffset2(int clampxplus4_filterPresenceOffset2) {
      this.clampxplus4_filterPresenceOffset2 = clampxplus4_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus4_filterPresenceStatus(String clampxplus4_filterPresenceStatus) {
      this.clampxplus4_filterPresenceStatus = clampxplus4_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus4_lockSensorOffset1(int clampxplus4_lockSensorOffset1) {
      this.clampxplus4_lockSensorOffset1 = clampxplus4_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus4_lockSensorValue(int clampxplus4_lockSensorValue) {
      this.clampxplus4_lockSensorValue = clampxplus4_lockSensorValue;
      return this;
    }

    public Builder clampxplus4_lockStatus(String clampxplus4_lockStatus) {
      this.clampxplus4_lockStatus = clampxplus4_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Builder socketID(int socketID) {
      this.socketID = socketID;
      return this;
    }

    public Fcs_Carousel_Socket4_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket4_TrendingTelemetry(atStandby, clampxminus4_clampState, clampxminus4_filterPositionSensorValue, clampxminus4_filterPresenceOffset2, clampxminus4_filterPresenceStatus, clampxminus4_lockSensorOffset1, clampxminus4_lockSensorValue, clampxminus4_lockStatus, clampxplus4_clampState, clampxplus4_filterPositionSensorValue, clampxplus4_filterPresenceOffset2, clampxplus4_filterPresenceStatus, clampxplus4_lockSensorOffset1, clampxplus4_lockSensorValue, clampxplus4_lockStatus, clampsState, empty, filterName, ioStatus, socketID);
    }
  }
}
